use strict;

package CPAN::Test::Dummy::Perl5::Make::OptionalPrereq;

$CPAN::Test::Dummy::Perl5::Make::OptionalPrereq::VERSION = '1.00';

1;

__END__

=pod

=head1 NAME

CPAN::Test::Dummy::Perl5::Make::OptionalPrereq - CPAN Test Dummy

=head1 SYNOPSIS

    use CPAN::Test::Dummy::Perl5::Make::OptionalPrereq;

=head1 DESCRIPTION

This module is part of CPAN.pm with the single purpose of testing
CPAN.pm itself.

Contains no functionality, and will never do so.

=head1 AUTHOR

Andreas Koenig.

=head1 COPYRIGHT & LICENSE

Copyright 2013 Andreas Koenig

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut
